@@ -49,7 +49,7 @@ Rose::DB::Object::Metadata::Column::Array - Array column metadata.
 
 Objects of this class store and manipulate metadata for array columns in a database.  Column metadata objects store information about columns (data type, size, etc.) and are responsible for creating object methods that manipulate column values.
 
-This class inherits from C<Rose::DB::Object::Metadata::Column>. Inherited methods that are not overridden will not be documented a second time here.  See the C<Rose::DB::Object::Metadata::Column> documentation for more information.
+This class inherits from L<Rose::DB::Object::Metadata::Column>. Inherited methods that are not overridden will not be documented a second time here.  See the L<Rose::DB::Object::Metadata::Column> documentation for more information.
 
 =head1 OBJECT METHODS
 
@@ -65,7 +65,7 @@ Get or set the dimensions of the column as a reference to an array of integer di
 
 =item B<method_maker_class>
 
-Returns C<Rose::DB::Object::MakeMethods::Generic>.
+Returns L<Rose::DB::Object::MakeMethods::Generic>.
 
 =item B<method_maker_type>
 
@@ -73,7 +73,7 @@ Returns C<array>.
 
 =item B<parse_value DB, VALUE>
 
-Parse VALUE and return a reference to an array containing the array values.  DB is a C<Rose::DB> object that is  used as part of the parsing process.  Both arguments are required.
+Parse VALUE and return a reference to an array containing the array values.  DB is a L<Rose::DB> object that is  used as part of the parsing process.  Both arguments are required.
 
 =item B<type>
 
